/*
    SPDX-FileCopyrightText: 2018 Roman Gilg <subdiff@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once

#include <KPluginFactory>

K_PLUGIN_FACTORY_DECLARATION(MousePluginFactory)
